@@ -2,7 +2,7 @@ import logging
 from mkdocs.utils import warning_filter
 
 # Set up a logger for my code to use
-LOGGER = logging.getLogger(f"mkdocs.plugins.placeholder")
+LOGGER = logging.getLogger("mkdocs.plugins.placeholder")
 LOGGER.addFilter(warning_filter)
 
 def warning(message: str) -> None:
